@@ -3,9 +3,12 @@
 #' Calculate the False Positive Rate (FPR) for each feature using it's selection frequency
 #'
 #' @param x a `randomForest` or `ranger` object
-#' @return a `data.frame` of selection frequencies and their false positive rate
+#' @return a `tibble` of selection frequencies and their false positive rate
 #'
 #' @author Jasen Finch \email{jsf9@@aber.ac.uk}
+#' @importFrom purrr map_dbl
+#' @importFrom magrittr %>%
+#' @importFrom dplyr left_join
 #' @export
 #' @examples
 #' library(randomForest)
@@ -28,9 +31,10 @@ fpr_fs <- function(x)
 
   params <- extract_params(x)
   freq <- selection_freqs(x)
-  fpr <- lapply(freq$freq, function(x){fpr_fs_calc(k = x,Ft = params$Ft, Fn = params$Fn, Tr = params$Tr, K = params$K)})
+  fpr <- map_dbl(unique(freq$freq),fpr_fs_calc,Ft = params$Ft, Fn = params$Fn, Tr = params$Tr, K = params$K) %>%
+  {tibble(freq = unique(freq$freq),fpr = .)}
 
-  feat_sel <- data.frame(freq, fpr = unlist(fpr))
+  feat_sel <- left_join(freq,fpr, by = "freq")
 
   return(feat_sel)
   }
